@@ -58,7 +58,17 @@ pub  fn half_life(&self)->f64{
            }
        }
        
-    /// Returns the probable decay modes  as a string 
+/** Returns the probable decay modes  as a string 
+    
+ ```
+     
+       use Nuclide::Nuclide;
+       
+       let beryllium = Nuclide::new("Be-12").unwrap();
+       assert_eq!(beryllium.decay_mode(),"99.5% β−; 0.5% β− + n; ")
+       
+ ```
+*/
    pub fn decay_mode(&self)-> String{
    
   let mut unu_alea   =   ((DECAY_CHAIN[(self.nuclide_index()*6)] as f64/18446744073709552000f64)*100.0).to_string(); 
@@ -139,7 +149,7 @@ pub  fn half_life(&self)->f64{
 
 
 
-/// Perfroms a maximum of one decay in the time given
+/// Performs a maximum of one decay in the time given
 pub fn static_decay(&mut self, time: f64)->(f64,Vec<Particle>) {
  
 let mut particle_vector = vec![];
@@ -181,8 +191,8 @@ match x {
     1  => {  //1 alpha
             izotop.0-=2; izotop.1-=2;  
             let daughter= Nuclide::assign(nucleons_nuclide(&izotop) );
-            let totalenergia = (self.amu()- daughter.amu())*931.49410242;
-            let particleenergia = totalenergia -(ALPHAMASS/self.amu())* totalenergia ; 
+            let totalenergia = (self.am()- daughter.am())*931.49410242;
+            let particleenergia = totalenergia -(ALPHAMASS/self.am())* totalenergia ; 
              energia = totalenergia-particleenergia;
              self.change(daughter.nuclide_index());
              particle_vector.push(Particle::Alpha(particleenergia));
@@ -190,8 +200,8 @@ match x {
     2  => {       // 1p
             izotop.0-=1;
             let daughter= Nuclide::assign(nucleons_nuclide(&izotop) );
-            let totalenergia = (self.amu()- daughter.amu())*931.49410242;
-            let particleenergia = totalenergia -(PROTONMASS/self.amu())* totalenergia ; 
+            let totalenergia = (self.am()- daughter.am())*931.49410242;
+            let particleenergia = totalenergia -(PROTONMASS/self.am())* totalenergia ; 
              energia = totalenergia-particleenergia;
              self.change(daughter.nuclide_index());
              particle_vector.push(Particle::Baryon( Baryon::Proton(particleenergia) ) );
@@ -199,8 +209,8 @@ match x {
     3  => {                    // 2p
             izotop.0-=2;
             let daughter= Nuclide::assign(nucleons_nuclide(&izotop) );
-            let totalenergia = (self.amu()- daughter.amu())*931.49410242;
-            let particleenergia = totalenergia -(2.0*PROTONMASS/self.amu())* totalenergia ;   
+            let totalenergia = (self.am()- daughter.am())*931.49410242;
+            let particleenergia = totalenergia -(2.0*PROTONMASS/self.am())* totalenergia ;   
              energia = totalenergia-particleenergia;
              self.change(daughter.nuclide_index());
              particle_vector.push(Particle::Baryon( Baryon::Proton(particleenergia/2.0) ));
@@ -209,8 +219,8 @@ match x {
     4  => {          // n 
                   izotop.1-=1;
             let daughter= Nuclide::assign(nucleons_nuclide(&izotop) );
-            let totalenergia = (self.amu()- daughter.amu())*931.49410242;
-            let particleenergia = totalenergia -(NEUTRONMASS/self.amu())* totalenergia ; 
+            let totalenergia = (self.am()- daughter.am())*931.49410242;
+            let particleenergia = totalenergia -(NEUTRONMASS/self.am())* totalenergia ; 
             energia = totalenergia-particleenergia;
              self.change(daughter.nuclide_index());
              particle_vector.push(Particle::Baryon( Baryon::Neutron(particleenergia) ));            
@@ -218,18 +228,18 @@ match x {
     5  => {          // 2n 
                   izotop.1-=2;
             let daughter= Nuclide::assign(nucleons_nuclide(&izotop) );
-            let totalenergia = (self.amu()- daughter.amu())*931.49410242;
-            let particleenergia = totalenergia -(2.0*NEUTRONMASS/self.amu())* totalenergia ;
+            let totalenergia = (self.am()- daughter.am())*931.49410242;
+            let particleenergia = totalenergia -(2.0*NEUTRONMASS/self.am())* totalenergia ;
              energia = totalenergia-particleenergia;
              self.change(daughter.nuclide_index());
              particle_vector.push(Particle::Baryon( Baryon::Neutron(particleenergia/2.0) ));
              particle_vector.push(Particle::Baryon( Baryon::Neutron(particleenergia/2.0) ));       
           }      
-    6  => {        println!("6");            // Electron capture
+    6  => {                   // Electron capture
                   izotop.0-=1; izotop.1+=1;
             let daughter= Nuclide::assign(nucleons_nuclide(&izotop) );
-            let totalenergia = (self.amu()- daughter.amu())*931.49410242;
-            let particleenergia = totalenergia -(NEUTRINOMASS/self.amu())* totalenergia ;
+            let totalenergia = (self.am()- daughter.am())*931.49410242;
+            let particleenergia = totalenergia -(NEUTRINOMASS/self.am())* totalenergia ;
             energia = totalenergia-particleenergia;
             self.change(daughter.nuclide_index());
             particle_vector.push(Particle::Lepton( Lepton::ElectronNeutrino(particleenergia) ));
@@ -237,8 +247,8 @@ match x {
     7  => {            // Double Electron Capture
                   izotop.0-=2; izotop.1+=2;
             let daughter= Nuclide::assign(nucleons_nuclide(&izotop) );
-            let totalenergia = (self.amu()- daughter.amu())*931.49410242;
-            let particleenergia = totalenergia -(2.0*NEUTRINOMASS/self.amu())* totalenergia ;
+            let totalenergia = (self.am()- daughter.am())*931.49410242;
+            let particleenergia = totalenergia -(2.0*NEUTRINOMASS/self.am())* totalenergia ;
             energia = totalenergia-particleenergia;
             self.change(daughter.nuclide_index());
             particle_vector.push(Particle::Lepton( Lepton::ElectronNeutrino(particleenergia/2.0) ));
@@ -247,8 +257,8 @@ match x {
     8  => {                    // B-p  particleenergia*2.35E-7*ELECTRONMASS
             izotop.1-=1; 
             let daughter= Nuclide::assign(nucleons_nuclide(&izotop) );
-            let totalenergia = (self.amu()- daughter.amu())*931.49410242;
-            let particleenergia = totalenergia -((ELECTRONMASS+NEUTRINOMASS+PROTONMASS)/self.amu())* totalenergia ;   
+            let totalenergia = (self.am()- daughter.am())*931.49410242;
+            let particleenergia = totalenergia -((ELECTRONMASS+NEUTRINOMASS+PROTONMASS)/self.am())* totalenergia ;   
             let protonenergia  = particleenergia - particleenergia*2.35E-7;
             energia = totalenergia - particleenergia ;
             particle_vector.push(Particle::Baryon( Baryon::Proton(protonenergia) ) );
@@ -258,8 +268,8 @@ match x {
     9  => {          // Beta +  http://hyperphysics.phy-astr.gsu.edu/hbase/Nuclear/beta2.html#c1
                   izotop.0-=1; izotop.1+=1;
             let daughter= Nuclide::assign(nucleons_nuclide(&izotop) );
-            let totalenergia = (self.amu()- daughter.amu())*931.49410242;
-            let particleenergia = totalenergia -((ELECTRONMASS+NEUTRINOMASS)/self.amu())* totalenergia ;  
+            let totalenergia = (self.am()- daughter.am())*931.49410242;
+            let particleenergia = totalenergia -((ELECTRONMASS+NEUTRINOMASS)/self.am())* totalenergia ;  
             energia = totalenergia - particleenergia ; 
             particle_vector.push(Particle::AntiLepton( AntiLepton::Electron(particleenergia*(1.0-2.35E-7) ) ));  
             particle_vector.push(Particle::Lepton(Lepton::ElectronNeutrino(particleenergia*2.35E-7)));              
@@ -267,8 +277,8 @@ match x {
    10  => {            // Double Beta + 
                   izotop.0-=2; izotop.1+=2;
             let daughter= Nuclide::assign(nucleons_nuclide(&izotop) );
-            let totalenergia = (self.amu()- daughter.amu())*931.49410242;
-            let particleenergia = totalenergia -((ELECTRONMASS+NEUTRINOMASS)*2.0/self.amu())* totalenergia ;  
+            let totalenergia = (self.am()- daughter.am())*931.49410242;
+            let particleenergia = totalenergia -((ELECTRONMASS+NEUTRINOMASS)*2.0/self.am())* totalenergia ;  
             energia = totalenergia - particleenergia ;
             particle_vector.push(Particle::AntiLepton(AntiLepton::Electron(particleenergia*(1.0-2.35E-7)*0.5) ) );  
             particle_vector.push(Particle::AntiLepton(AntiLepton::Electron(particleenergia*(1.0-2.35E-7)*0.5) ) );  
@@ -278,8 +288,8 @@ match x {
    11  => {           // Beta -
                   izotop.0+=1; izotop.1-=1;
             let daughter= Nuclide::assign(nucleons_nuclide(&izotop) );
-            let totalenergia = (self.amu() -daughter.amu())*931.49410242;;
-            let particleenergia = totalenergia -((ELECTRONMASS+NEUTRINOMASS)/self.amu())* totalenergia ; 
+            let totalenergia = (self.am() -daughter.am())*931.49410242;
+            let particleenergia = totalenergia -((ELECTRONMASS+NEUTRINOMASS)/self.am())* totalenergia ; 
             energia = totalenergia - particleenergia ;
             particle_vector.push(Particle::Lepton(Lepton::Electron(particleenergia*(1.0-2.35E-7))));  
             particle_vector.push(Particle::AntiLepton(AntiLepton::ElectronNeutrino(particleenergia*2.35E-7)));
@@ -288,9 +298,9 @@ match x {
    12  => {          // Double Beta -
                   izotop.0+=2; izotop.1-=2;
             let daughter= Nuclide::assign(nucleons_nuclide(&izotop) );
-            let mass_delta = self.amu() -daughter.amu(); 
-            let totalenergia = (self.amu()- daughter.amu())*931.49410242;
-            let particleenergia = totalenergia -((ELECTRONMASS+NEUTRINOMASS)*2.0/self.amu())* totalenergia ;  
+            let mass_delta = self.am() -daughter.am(); 
+            let totalenergia = (self.am()- daughter.am())*931.49410242;
+            let particleenergia = totalenergia -((ELECTRONMASS+NEUTRINOMASS)*2.0/self.am())* totalenergia ;  
             energia = totalenergia - particleenergia ;
             particle_vector.push(Particle::Lepton(Lepton::Electron(particleenergia*(1.0-2.35E-7)*0.5)));  
             particle_vector.push(Particle::Lepton(Lepton::Electron(particleenergia*(1.0-2.35E-7)*0.5)));  
@@ -300,8 +310,8 @@ match x {
    13  => {                    // B- + n 
                   izotop.0+=1; izotop.1-=2; 
             let daughter= Nuclide::assign(nucleons_nuclide(&izotop) );
-            let totalenergia = (self.amu()- daughter.amu())*931.49410242;
-            let particleenergia = totalenergia -((ELECTRONMASS+NEUTRINOMASS+NEUTRONMASS)/self.amu())* totalenergia ;   
+            let totalenergia = (self.am()- daughter.am())*931.49410242;
+            let particleenergia = totalenergia -((ELECTRONMASS+NEUTRINOMASS+NEUTRONMASS)/self.am())* totalenergia ;   
             let neutronenergia  = particleenergia - particleenergia*2.35E-7;
             energia = totalenergia - particleenergia ;
             particle_vector.push(Particle::Baryon(Baryon::Neutron(neutronenergia)));
@@ -312,8 +322,8 @@ match x {
                   izotop.0+=1; izotop.1-=3; 
                   
             let daughter= Nuclide::assign(nucleons_nuclide(&izotop) );
-            let totalenergia = (self.amu()- daughter.amu())*931.49410242;
-            let particleenergia = totalenergia -((ELECTRONMASS+NEUTRINOMASS+2.0*NEUTRONMASS)/self.amu())* totalenergia ;   
+            let totalenergia = (self.am()- daughter.am())*931.49410242;
+            let particleenergia = totalenergia -((ELECTRONMASS+NEUTRINOMASS+2.0*NEUTRONMASS)/self.am())* totalenergia ;   
             let neutronenergia  = particleenergia - particleenergia*2.35E-7;   
             energia = totalenergia - particleenergia ;       
             particle_vector.push(Particle::Baryon( Baryon::Neutron(particleenergia/2.0) ));
@@ -324,8 +334,8 @@ match x {
    15  => {                    // B- + 3n
             izotop.0+=1; izotop.1-=4; 
             let daughter= Nuclide::assign(nucleons_nuclide(&izotop) );
-            let totalenergia = (self.amu()- daughter.amu())*931.49410242;
-            let particleenergia = totalenergia -((ELECTRONMASS+NEUTRINOMASS+3.0*NEUTRONMASS)/self.amu())* totalenergia ;   
+            let totalenergia = (self.am()- daughter.am())*931.49410242;
+            let particleenergia = totalenergia -((ELECTRONMASS+NEUTRINOMASS+3.0*NEUTRONMASS)/self.am())* totalenergia ;   
             let neutronenergia  = particleenergia - particleenergia*2.35E-7;
             energia = totalenergia - particleenergia ;
             particle_vector.push(Particle::Baryon( Baryon::Neutron(particleenergia/3.0) ));
@@ -337,8 +347,8 @@ match x {
    16  => {                    // B+ + p
             izotop.0-=2; izotop.1+=1;
             let daughter= Nuclide::assign(nucleons_nuclide(&izotop) );
-            let totalenergia = (self.amu()- daughter.amu())*931.49410242;
-            let particleenergia = totalenergia -((ELECTRONMASS+NEUTRINOMASS+PROTONMASS)/self.amu())* totalenergia  ;
+            let totalenergia = (self.am()- daughter.am())*931.49410242;
+            let particleenergia = totalenergia -((ELECTRONMASS+NEUTRINOMASS+PROTONMASS)/self.am())* totalenergia  ;
             let protonenergia  = particleenergia - particleenergia*2.35E-7; 
             energia = totalenergia - particleenergia ;
             particle_vector.push(Particle::Baryon( Baryon::Proton(protonenergia) ) );
@@ -348,8 +358,8 @@ match x {
    17  => {                    // B+ + 2p
             izotop.0-=3; izotop.1+=1;
             let daughter= Nuclide::assign(nucleons_nuclide(&izotop) );
-            let totalenergia = (self.amu()- daughter.amu())*931.49410242;
-            let particleenergia = totalenergia -((ELECTRONMASS+NEUTRINOMASS+2.0*PROTONMASS)/self.amu())* totalenergia  ;
+            let totalenergia = (self.am()- daughter.am())*931.49410242;
+            let particleenergia = totalenergia -((ELECTRONMASS+NEUTRINOMASS+2.0*PROTONMASS)/self.am())* totalenergia  ;
             let protonenergia  = particleenergia - particleenergia*2.35E-7; 
             energia = totalenergia - particleenergia ;
             particle_vector.push(Particle::Baryon( Baryon::Proton(protonenergia/2.0) ) );
@@ -360,8 +370,8 @@ match x {
    18  => {                    // B+ + 3p
             izotop.0-=4; izotop.1+=1;
             let daughter= Nuclide::assign(nucleons_nuclide(&izotop) );
-            let totalenergia = (self.amu()- daughter.amu())*931.49410242;
-            let particleenergia = totalenergia -((ELECTRONMASS+NEUTRINOMASS+3.0*PROTONMASS)/self.amu())* totalenergia;  
+            let totalenergia = (self.am()- daughter.am())*931.49410242;
+            let particleenergia = totalenergia -((ELECTRONMASS+NEUTRINOMASS+3.0*PROTONMASS)/self.am())* totalenergia;  
             let protonenergia  = particleenergia - particleenergia*2.35E-7; 
             energia = totalenergia - particleenergia ;
             particle_vector.push(Particle::Baryon( Baryon::Proton(protonenergia/3.0) ) );
@@ -374,8 +384,8 @@ match x {
    19  => {                    // B- + A 
                   izotop.0-=1; izotop.1-=3;
             let daughter= Nuclide::assign(nucleons_nuclide(&izotop) );
-            let totalenergia = (self.amu()- daughter.amu())*931.49410242;
-            let particleenergia = totalenergia -((ELECTRONMASS+NEUTRINOMASS+ALPHAMASS)/self.amu())* totalenergia ;  
+            let totalenergia = (self.am()- daughter.am())*931.49410242;
+            let particleenergia = totalenergia -((ELECTRONMASS+NEUTRINOMASS+ALPHAMASS)/self.am())* totalenergia ;  
             let alphaenergia  = particleenergia - particleenergia*2.35E-7; 
             energia = totalenergia - particleenergia ;
             particle_vector.push(Particle::Alpha(alphaenergia));    
@@ -385,8 +395,8 @@ match x {
    20  => {                    // B+ + A
                   izotop.0-=3; izotop.1-=1;
             let daughter= Nuclide::assign(nucleons_nuclide(&izotop) );
-            let totalenergia = (self.amu()- daughter.amu())*931.49410242;
-            let particleenergia = totalenergia -((ELECTRONMASS+NEUTRINOMASS+ALPHAMASS)/self.amu())* totalenergia ;   
+            let totalenergia = (self.am()- daughter.am())*931.49410242;
+            let particleenergia = totalenergia -((ELECTRONMASS+NEUTRINOMASS+ALPHAMASS)/self.am())* totalenergia ;   
             let alphaenergia  = particleenergia - particleenergia*2.35E-7; 
             energia = totalenergia - particleenergia ;
             particle_vector.push(Particle::Alpha(alphaenergia));    
@@ -396,8 +406,8 @@ match x {
    21  => {                    // B- + Deuteron 
                   izotop.1-=3; 
             let daughter= Nuclide::assign(nucleons_nuclide(&izotop) );
-            let totalenergia = (self.amu()- daughter.amu())*931.49410242;
-            let particleenergia = totalenergia -((ELECTRONMASS+NEUTRINOMASS+DEUTERONMASS)/self.amu())* totalenergia   ;  
+            let totalenergia = (self.am()- daughter.am())*931.49410242;
+            let particleenergia = totalenergia -((ELECTRONMASS+NEUTRINOMASS+DEUTERONMASS)/self.am())* totalenergia   ;  
             let deuteronenergia  = particleenergia - particleenergia*2.35E-7; 
             energia = totalenergia - particleenergia ;
             particle_vector.push(Particle::Deuteron(deuteronenergia));    
@@ -407,8 +417,8 @@ match x {
    22  => {                    // B- + Triton
                   izotop.1-=4;     
             let daughter= Nuclide::assign(nucleons_nuclide(&izotop) );
-            let totalenergia = (self.amu()- daughter.amu())*931.49410242;
-            let particleenergia = totalenergia -((ELECTRONMASS+NEUTRINOMASS+TRITONMASS)/self.amu())* totalenergia   ;  
+            let totalenergia = (self.am()- daughter.am())*931.49410242;
+            let particleenergia = totalenergia -((ELECTRONMASS+NEUTRINOMASS+TRITONMASS)/self.am())* totalenergia   ;  
             let tritonenergia  = particleenergia - particleenergia*2.35E-7; 
             energia = totalenergia - particleenergia ;
             particle_vector.push(Particle::Triton(tritonenergia));    
@@ -421,8 +431,8 @@ match x {
              let iso = decay_particle.proton_neutron() ;
              izotop.0-=iso.0 ; izotop.1-=iso.1 ;
              let daughter = Nuclide::assign(nucleons_nuclide(&izotop));
-             let totalenergia = (self.amu()- daughter.amu())*931.49410242;
-             let particleenergia = totalenergia -(decay_particle.amu()/self.amu())* totalenergia;  
+             let totalenergia = (self.am()- daughter.am())*931.49410242;
+             let particleenergia = totalenergia -(decay_particle.am()/self.am())* totalenergia;  
              energia = totalenergia - particleenergia ;
               particle_vector.push(Particle::Element(decay_particle,particleenergia));
              
@@ -434,8 +444,8 @@ match x {
              let iso = decay_particle.proton_neutron() ;
              izotop.0-=(iso.0-1) ; izotop.1-=(iso.1+1) ;
              let daughter = Nuclide::assign(nucleons_nuclide(&izotop));
-             let totalenergia = (self.amu()- daughter.amu())*931.49410242;
-             let particleenergia = (daughter.amu()/self.amu())* totalenergia ;  
+             let totalenergia = (self.am()- daughter.am())*931.49410242;
+             let particleenergia = (daughter.am()/self.am())* totalenergia ;  
              energia = totalenergia - particleenergia ;
              particle_vector.push(Particle::Element(decay_particle,particleenergia));
              particle_vector.push(Particle::Lepton(Lepton::Electron(particleenergia*(1.0-2.35E-7))));  
@@ -447,8 +457,8 @@ match x {
              let iso = decay_particle.proton_neutron() ;
              izotop.0-=(iso.0-1) ; izotop.1-=(iso.1+1) ;
              let daughter = Nuclide::assign(nucleons_nuclide(&izotop));
-             let totalenergia = (self.amu()- daughter.amu())*931.49410242;
-             let particleenergia = (daughter.amu()/self.amu())* totalenergia ;  
+             let totalenergia = (self.am()- daughter.am())*931.49410242;
+             let particleenergia = (daughter.am()/self.am())* totalenergia ;  
              energia = totalenergia - particleenergia ;
              particle_vector.push(Particle::Element(decay_particle,particleenergia));
              particle_vector.push(Particle::AntiLepton(AntiLepton::Electron(particleenergia*(1.0-2.35E-7))));  
@@ -457,18 +467,18 @@ match x {
    26  => {                    // CD C14 
                    izotop.0-=6; izotop.1-=8;                        
             let daughter= Nuclide::assign(nucleons_nuclide(&izotop) );
-            let totalenergia = (self.amu()- daughter.amu())*931.49410242;
+            let totalenergia = (self.am()- daughter.am())*931.49410242;
             let c14 = Nuclide::assign(60usize);
-            let particleenergia = totalenergia - (c14.amu()/self.amu())* totalenergia ;  
+            let particleenergia = totalenergia - (c14.am()/self.am())* totalenergia ;  
             energia = totalenergia - particleenergia ;
             particle_vector.push(Particle::Element(c14,particleenergia));       //  missing value   
           } ,
    27  => {                    // Ne-20
                izotop.0-=10; izotop.1-=10;                        
             let daughter= Nuclide::assign(nucleons_nuclide(&izotop) );
-            let totalenergia = (self.amu()- daughter.amu())*931.49410242;
+            let totalenergia = (self.am()- daughter.am())*931.49410242;
             let Ne20 = Nuclide::assign(128usize);
-            let particleenergia = totalenergia - (Ne20.amu()/self.amu())* totalenergia ;  
+            let particleenergia = totalenergia - (Ne20.am()/self.am())* totalenergia ;  
             energia = totalenergia - particleenergia ; 
             particle_vector.push(Particle::Element(Ne20,particleenergia));                                 
           } ,                                   
@@ -476,9 +486,9 @@ match x {
    28  => {                    //  Ne-24
             izotop.0-=10; izotop.1-=14;                        
             let daughter= Nuclide::assign(nucleons_nuclide(&izotop) );
-            let totalenergia = (self.amu()- daughter.amu())*931.49410242;
+            let totalenergia = (self.am()- daughter.am())*931.49410242;
             let Ne24 = Nuclide::assign(132usize);
-            let particleenergia = totalenergia - (Ne24.amu()/self.amu())* totalenergia ; 
+            let particleenergia = totalenergia - (Ne24.am()/self.am())* totalenergia ; 
             energia = totalenergia - particleenergia ;   
             particle_vector.push(Particle::Element(Ne24,particleenergia));                                          
           } ,
@@ -486,10 +496,10 @@ match x {
    29  => {                  // Ne-26 + Ne-24                    // correct decay energys
             izotop.0-=20; izotop.1-=30;                        
             let daughter= Nuclide::assign(nucleons_nuclide(&izotop) );
-            let totalenergia = (self.amu()- daughter.amu())*931.49410242;
+            let totalenergia = (self.am()- daughter.am())*931.49410242;
             let Ne24 = Nuclide::assign(132usize); let Ne26 = Nuclide::assign(134usize);
-            let particleenergia = totalenergia - ((Ne24.amu() + Ne26.amu())/self.amu())* totalenergia ; 
-            let neonenergia  = particleenergia -(Ne24.amu()/(Ne26.amu()+Ne24.amu()))*particleenergia; 
+            let particleenergia = totalenergia - ((Ne24.am() + Ne26.am())/self.am())* totalenergia ; 
+            let neonenergia  = particleenergia -(Ne24.am()/(Ne26.am()+Ne24.am()))*particleenergia; 
             particle_vector.push(Particle::Element(Ne24,neonenergia)); 
             particle_vector.push(Particle::Element(Ne26,particleenergia-neonenergia));       
           } ,                     
@@ -498,18 +508,18 @@ match x {
    30  => {                   // Si-32
              izotop.0-=14; izotop.1-=18;                        
             let daughter= Nuclide::assign(nucleons_nuclide(&izotop) );
-            let totalenergia = (self.amu()- daughter.amu())*931.49410242;
+            let totalenergia = (self.am()- daughter.am())*931.49410242;
             let Si32 = Nuclide::assign(224usize);
-            let particleenergia = totalenergia - (Si32.amu()/self.amu())* totalenergia ;  
+            let particleenergia = totalenergia - (Si32.am()/self.am())* totalenergia ;  
            energia = totalenergia - particleenergia ; 
            particle_vector.push(Particle::Element(Si32,particleenergia)); 
           } ,    
    31  => {                   // Si-34
              izotop.0-=14; izotop.1-=20;                        
             let daughter= Nuclide::assign(nucleons_nuclide(&izotop) );
-            let totalenergia = (self.amu()- daughter.amu())*931.49410242;
+            let totalenergia = (self.am()- daughter.am())*931.49410242;
             let Si34 = Nuclide::assign(226usize);
-            let particleenergia = totalenergia - (Si34.amu()/self.amu())* totalenergia ;  
+            let particleenergia = totalenergia - (Si34.am()/self.am())* totalenergia ;  
            energia = totalenergia - particleenergia ; 
            particle_vector.push(Particle::Element(Si34,particleenergia)); 
           }
@@ -525,7 +535,8 @@ match x {
      Returns the name and isotope number of the nuclide
      
         ```
-        let uranium = Nuclide::new("U", 238).unwrap();
+        use Nuclide::Nuclide;
+        let mut uranium = Nuclide::new("U-238").unwrap();
         
        // total particle energy of the nuclide and vector of decay particles
         let (particle_energy,particle_vector) = uranium.decay(5E+20);
