@@ -6,7 +6,6 @@
                 mod electro;
                 mod radii;
                 mod index    ;
-                mod update   ;
                 mod half_life;
                 mod decay    ;
                 mod decay_chain;
@@ -15,9 +14,10 @@
                 mod ionization ;
                 mod spinparity ;
                 mod particle   ;
-                use nuclide::Nuclide;
+               pub use nuclide::Nuclide;
+
                 
-
+ 
 
 
 
