@@ -1,4 +1,4 @@
-//mod index;
+
 use crate::index::SYMBOL;
 use crate::index::SYMBOL_INDEX;
 use crate::index::NAME;
@@ -8,8 +8,8 @@ use crate::spinparity::SPIN_PARITY;
 use crate::particle::PROTONMASS;
 use crate::particle::NEUTRONMASS;
 
-/// Takes the proton_neutron count and returns the nuclide index, useful to pair with change and assign
-pub fn nucleons_nuclide(x: &(usize, usize))-> usize{
+// Takes the proton_neutron count and returns the nuclide index, useful to pair with change and assign
+pub (crate) fn nucleons_nuclide(x: &(usize, usize))-> usize{
     SYMBOL_INDEX[x.0-1].0 -(SYMBOL_INDEX[x.0 -1].1-x.0) + x.1 
  }
  
@@ -18,7 +18,7 @@ pub fn nucleons_nuclide(x: &(usize, usize))-> usize{
      computing the binding_energy, and  proton/neutron separation energies
  */
  
-pub fn mass_model(a: usize, z: usize)->f64{
+pub (crate) fn mass_model(a: usize, z: usize)->f64{
 
    let (af64, zf64) = (a as f64, z as f64);
 
@@ -41,32 +41,38 @@ pub fn mass_model(a: usize, z: usize)->f64{
 
 
 
-#[derive(Debug)]
+#[derive(Debug, Clone)]
  pub struct Nuclide{
      nuclide: usize,
 }
 
 
-impl Clone for Nuclide{
-  fn clone(&self)->Nuclide{
-  Nuclide{nuclide: self.nuclide.clone()}
-  }
-}
 
 impl Nuclide{
 /**This function takes the symbol abbreviation and the isotope number.  For example to get the nuclide for Strontium-90
 ```
-use Nuclide::nuclide::Nuclide;
+use Nuclide::Nuclide;
 
- let strontium = Nuclide::new("Sr", 90).unwrap();
+ let strontium = Nuclide::new("Sr-90").unwrap();
  ```
-If you input an abbreviation that isn't supported or an isotope that isn't supported you will receive an error saying so. There are currently 3585 nuclides supported, which will cover most needs.
+If you input an abbreviation that isn't supported or an isotope that isn't supported you will receive an error saying so. There are currently 3585 nuclides supported, which will cover most needs as it is all the nuclides known to exist .
 */
 
 
 
-  pub fn new(x: &str, isotope: usize)-> Result<Nuclide,&'static str >{
- 
+  pub fn new(input: &str)-> Result<Self,&'static str >{ // input   // x: &str, isotope: usize
+     let mut isotope = 0usize;
+     let z = input.split('-').collect::<Vec<&str>>();
+     if z.len() != 2{
+       return Err("Incorrect Syntax")
+     }
+     match z[1].parse::<usize>(){
+       Ok(y) => isotope = y ,
+       _ => return Err("Incorrect Syntax"),
+     }
+     
+     let x = z[0];
+     
          match SYMBOL.iter().position(|y| y ==&x){
           Some(x)=> if isotope >= SYMBOL_INDEX[x].1 &&  isotope <= SYMBOL_INDEX[x].2 {
                        return Ok(
@@ -80,26 +86,23 @@ If you input an abbreviation that isn't supported or an isotope that isn't suppo
        }
        
        }
+       
+  pub fn from_nucleons(protons: usize, neutrons: usize) -> Self{
+          Nuclide::assign(nucleons_nuclide(&(protons,neutrons)))
+  }     
  
- /** Directly assigns the argument as the value. This function performs zero checks so it is up to the user to insure that the value given is correct. Pair with the nucleons_nuclide function to ensure that you have a correct value. 
  
- ```
- let nucleon_count = strontium.proton_neutron();
- let nuclide_index = nucleons_nuclide(&nucleon_count);
- 
- assert_eq!(nuclide_index, strontium.nuclide_index());
- 
- let strontium90   = Nuclide::assign(nuclide_index); 
- 
- ```
- 
- */
-  pub fn assign(x: usize)->Nuclide{
+  pub fn assign(x: usize)-> Self{
       Nuclide{nuclide: x}
   }
  /** Mutates the element in place to the argument given. Zero checks are made, so verify that it is correct
  
  ```
+ use Nuclide::Nuclide;
+ 
+ let radium = Nuclide::new("Ra-222").unwrap();
+ let mut strontium = Nuclide::new("Sr-90").unwrap();
+ 
  let radium_converter = radium.nuclide_index();
  
  strontium.change(radium_converter); 
@@ -111,14 +114,19 @@ If you input an abbreviation that isn't supported or an isotope that isn't suppo
   pub  fn change(&mut self, x: usize){
           self.nuclide = x
      }
-     /** Takes proton and neutron argument, returns a tuple of approximate mass and binding energy. Allows for approximation of theorectical nuclides, using the mass model
+     /** Takes proton and neutron argument, returns a tuple of approximate mass and binding energy. Allows for approximation of theorectical nuclides, 
+     using the Bethe-Weiszacker mass model
      
-        ```
-        let sr90 = Nuclide::create(38,52);
-                              // real computed value is 89.907 amu,782 MeV
-        assert_eq!(sr90, (89.893471169, 776.39792))
-        ```
-     */
+ ```
+ use Nuclide::Nuclide;
+ 
+ let sr90 = Nuclide::create(38,52);
+                     // real computed value is 89.907 am,782 MeV
+  assert_eq!(sr90, (89.89347116977667,776.3979272535155))
+ 
+ ```
+
+  */
   pub  fn create(z: usize, n: usize)-> (f64,f64){
       let b_e =  mass_model(z+n,z);
      ( (z as f64*PROTONMASS + n as f64*NEUTRONMASS) - (b_e/931.36808885),b_e)
@@ -154,7 +162,9 @@ pub  fn isotope(&self)->(usize, usize){
      Returns the name and isotope number of the nuclide
      
         ```
-        let radium = Nuclide::new("Ra", 222).unwrap();
+        use Nuclide::Nuclide;
+        
+        let radium = Nuclide::new("Ra-222").unwrap();
         
         assert_eq!(radium.identity(), "Ra-222");
         ```
@@ -163,32 +173,37 @@ pub  fn isotope(&self)->(usize, usize){
           let iso = self.isotope();
           SYMBOL[iso.0-1].to_owned() + "-"+ &iso.1.to_string()
        }
+       
    ///Returns the element name.     
   pub fn element_name(&self)->String{
          NAME[self.atomic_num()-1].to_string()
        }     
+       
  ///Returns the proton and neutron count 
   pub  fn proton_neutron(&self)->(usize, usize){
           (self.isotope().0,  self.isotope().1 - self.isotope().0)
        }
+       
        /// Returns the atomic mass in daltons 
-  pub  fn amu(&self)->f64{
+  pub  fn am(&self)->f64{
           ATOMIC_MASS[self.nuclide]
        }
+       
  ///Returns the atomic mass in kilograms
   pub  fn am_kg(&self)->f64{
-          self.amu()*1.6605390666E-27
+          self.am()*1.6605390666E-27
        }
        
   pub  fn mass_deficit(&self)->f64{
           let nucleons = self.proton_neutron();
           (1.007276466621*nucleons.0 as f64 + 5.48579909065E-4*nucleons.0 as f64
-           + 1.00866491588*nucleons.1 as f64)-self.amu()
+           + 1.00866491588*nucleons.1 as f64)-self.am()
        }
  
   pub  fn mass_deficit_kg(&self)->f64{
        self.mass_deficit()* 1.6605390666E-27
        }
+       
     /// Mass deficit as MeV   
   pub fn mass_deficit_ev(&self)->f64{
        self.mass_deficit()*931.36808885
